==> bellsoft-jdk21.0.9+11-src-full.tar.gz: jdk-21.0.9-full/openjfx/modules/javafx.base/src/test/java/test/javafx/collections/WeakListChangeListenerTest.java <==
/*
 * Copyright (c) 2011, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package test.javafx.collections;

import com.sun.javafx.collections.NonIterableChange;
import com.sun.javafx.collections.ObservableListWrapper;
import org.junit.Test;

import java.util.ArrayList;
import java.util.Collections;
import javafx.collections.ListChangeListener;
import javafx.collections.WeakListChangeListener;

import static org.junit.Assert.*;

public class WeakListChangeListenerTest {

    @Test(expected=NullPointerException.class)
    public void testConstructWithNull() {
        new WeakListChangeListener<>(null);
    }

    @Test
    public void testHandle() {
        MockListObserver<Object> listener = new MockListObserver<>();
        final WeakListChangeListener<Object> weakListener = new WeakListChangeListener<>(listener);
        final ObservableListWrapper<Object> list = new ObservableListWrapper<>(new ArrayList<>());
        final Object removedElement = new Object();
        final ListChangeListener.Change<Object> change = new NonIterableChange.SimpleRemovedChange<>(0, 1, removedElement, list);

        // regular call
        weakListener.onChanged(change);
        listener.check1AddRemove(list, Collections.singletonList(removedElement), 0, 1);
        assertFalse(weakListener.wasGarbageCollected());

        // GC-ed call
        listener = null;
        System.gc();
        assertTrue(weakListener.wasGarbageCollected());
        weakListener.onChanged(change);

    }

}

==> bellsoft-jdk25.0.1+13-src-full.tar.gz: jdk-25.0.1-full/openjfx/modules/javafx.base/src/test/java/test/javafx/collections/WeakListChangeListenerTest.java <==
/*
 * Copyright (c) 2011, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package test.javafx.collections;

import com.sun.javafx.collections.NonIterableChange;
import com.sun.javafx.collections.ObservableListWrapper;
import org.junit.jupiter.api.Test;

import java.util.ArrayList;
import java.util.Collections;
import javafx.collections.ListChangeListener;
import javafx.collections.WeakListChangeListener;

import static org.junit.jupiter.api.Assertions.*;

public class WeakListChangeListenerTest {

    @Test
    public void testConstructWithNull() {
        assertThrows(NullPointerException.class, () -> {
            new WeakListChangeListener<>(null);
        });
    }


    @Test
    public void testHandle() {
        MockListObserver<Object> listener = new MockListObserver<>();
        final WeakListChangeListener<Object> weakListener = new WeakListChangeListener<>(listener);
        final ObservableListWrapper<Object> list = new ObservableListWrapper<>(new ArrayList<>());
        final Object removedElement = new Object();
        final ListChangeListener.Change<Object> change = new NonIterableChange.SimpleRemovedChange<>(0, 1, removedElement, list);

        // regular call
        weakListener.onChanged(change);
        listener.check1AddRemove(list, Collections.singletonList(removedElement), 0, 1);
        assertFalse(weakListener.wasGarbageCollected());

        // GC-ed call
        listener = null;
        System.gc();
        assertTrue(weakListener.wasGarbageCollected());
        weakListener.onChanged(change);

    }

}
